@@ -39,7 +39,7 @@ PROJECT_ENV_MANAGER = "ENV_MANAGER"
 PROJECT_SYNCHRONOUS = "SYNCHRONOUS"
 PROJECT_DOCKER_ARGS = "DOCKER_ARGS"
 PROJECT_STORAGE_DIR = "STORAGE_DIR"
-SKIP_IMAGE_BUILD = "SKIP_IMAGE_BUILD"
+PROJECT_BUILD_IMAGE = "build_image"
 GIT_FETCH_DEPTH = 1
 
 
