@@ -1,7 +1,6 @@
 from collections import defaultdict, namedtuple, OrderedDict
 import logging
 import numpy as np
-import time
 import os
 from pkg_resources import resource_filename
 from urllib.parse import urlparse
@@ -39,6 +38,7 @@ from mlflow.utils.validation import (
 from mlflow.utils.autologging_utils import (
     INPUT_EXAMPLE_SAMPLE_ROWS,
 )
+from mlflow.utils.time_utils import get_current_time_millis
 
 _logger = logging.getLogger(__name__)
 _SparkTrainingSession = _get_new_training_session_class()
@@ -386,14 +386,14 @@ def _create_child_runs_for_parameter_search(parent_estimator, parent_model, pare
     # start time of child runs, since we cannot precisely determine when each point
     # in the parameter search space was explored
     child_run_start_time = parent_run.info.start_time
-    child_run_end_time = int(time.time() * 1000)
+    child_run_end_time = get_current_time_millis()
 
     estimator_param_maps = parent_estimator.getEstimatorParamMaps()
     tuned_estimator = parent_estimator.getEstimator()
 
     metrics_dict, _ = _get_param_search_metrics_and_best_index(parent_estimator, parent_model)
-    for i in range(len(estimator_param_maps)):
-        child_estimator = tuned_estimator.copy(estimator_param_maps[i])
+    for i, est_param in enumerate(estimator_param_maps):
+        child_estimator = tuned_estimator.copy(est_param)
         tags_to_log = dict(child_tags) if child_tags else {}
         tags_to_log.update({MLFLOW_PARENT_RUN_ID: parent_run.info.run_id})
         tags_to_log.update(_get_estimator_info_tags(child_estimator))
@@ -1003,7 +1003,7 @@ def autolog(
                 spark = SparkSession.builder.getOrCreate()
 
                 def _get_input_example_as_pd_df():
-                    feature_cols = list(get_feature_cols(input_df.schema, spark_model))
+                    feature_cols = list(get_feature_cols(input_df, spark_model))
                     limited_input_df = input_df.select(feature_cols).limit(
                         INPUT_EXAMPLE_SAMPLE_ROWS
                     )
