@@ -5,7 +5,6 @@ import re
 import tempfile
 import posixpath
 import urllib
-import pathlib
 
 import logging
 from functools import wraps
@@ -34,7 +33,6 @@ from mlflow.protos.service_pb2 import (
     LogMetric,
     LogParam,
     SetTag,
-    ListExperiments,
     SearchExperiments,
     DeleteExperiment,
     RestoreExperiment,
@@ -52,7 +50,6 @@ from mlflow.protos.model_registry_pb2 import (
     CreateRegisteredModel,
     UpdateRegisteredModel,
     DeleteRegisteredModel,
-    ListRegisteredModels,
     GetRegisteredModel,
     GetLatestVersions,
     CreateModelVersion,
@@ -81,14 +78,10 @@ from mlflow.store.artifact.artifact_repository_registry import get_artifact_repo
 from mlflow.store.db.db_types import DATABASE_ENGINES
 from mlflow.tracking._model_registry.registry import ModelRegistryStoreRegistry
 from mlflow.tracking._tracking_service.registry import TrackingStoreRegistry
-from mlflow.utils.name_utils import _generate_random_name
 from mlflow.utils.proto_json_utils import message_to_json, parse_dict
 from mlflow.utils.validation import _validate_batch_log_api_req
 from mlflow.utils.string_utils import is_string_type
-from mlflow.utils.uri import is_local_uri, is_file_uri
-from mlflow.utils.file_utils import local_file_uri_to_path
 from mlflow.tracking.registry import UnsupportedModelRegistryStoreURIException
-from mlflow.environment_variables import MLFLOW_ALLOW_FILE_URI_AS_MODEL_VERSION_SOURCE
 
 _logger = logging.getLogger(__name__)
 _tracking_store = None
@@ -502,7 +495,7 @@ def _disable_unless_serve_artifacts(func):
             return Response(
                 (
                     f"Endpoint: {request.url_rule} disabled due to the mlflow server running "
-                    "without `--serve-artifacts`. To enable artifacts server functionality, "
+                    "with `--no-serve-artifacts`. To enable artifacts server functionality, "
                     "run `mlflow server` with `--serve-artifacts`"
                 ),
                 503,
@@ -531,18 +524,22 @@ def _disable_if_artifacts_only(func):
     return wrapper
 
 
-_OS_ALT_SEPS = [sep for sep in [os.sep, os.path.altsep] if sep is not None and sep != "/"]
+_os_alt_seps = [sep for sep in [os.sep, os.path.altsep] if sep is not None and sep != "/"]
 
 
 def validate_path_is_safe(path):
     """
     Validates that the specified path is safe to join with a trusted prefix. This is a security
-    measure to prevent path traversal attacks.
+    measure to prevent path traversal attacks. The implementation is based on
+    `werkzeug.security.safe_join` (https://github.com/pallets/werkzeug/blob/a3005e6acda7246fe0a684c71921bf4882b4ba1c/src/werkzeug/security.py#L110).
     """
+    if path != "":
+        path = posixpath.normpath(path)
     if (
-        any((s in path) for s in _OS_ALT_SEPS)
-        or ".." in path.split(posixpath.sep)
-        or posixpath.isabs(path)
+        any(sep in path for sep in _os_alt_seps)
+        or os.path.isabs(path)
+        or path == ".."
+        or path.startswith("../")
     ):
         raise MlflowException(f"Invalid path: {path}", error_code=INVALID_PARAMETER_VALUE)
 
@@ -554,9 +551,9 @@ def get_artifact_handler():
     query_string = request.query_string.decode("utf-8")
     request_dict = parser.parse(query_string, normalized=True)
     run_id = request_dict.get("run_id") or request_dict.get("run_uuid")
-    run = _get_tracking_store().get_run(run_id)
     path = request_dict["path"]
     validate_path_is_safe(path)
+    run = _get_tracking_store().get_run(run_id)
 
     if _is_servable_proxied_run_artifact_root(run.info.artifact_uri):
         artifact_repo = _get_artifact_repo_mlflow_artifacts()
@@ -583,6 +580,7 @@ def _not_implemented():
 @catch_mlflow_exception
 @_disable_if_artifacts_only
 def _create_experiment():
+
     request_message = _get_request_message(
         CreateExperiment(),
         schema={
@@ -696,13 +694,12 @@ def _create_run():
     )
 
     tags = [RunTag(tag.key, tag.value) for tag in request_message.tags]
-    run_name = _generate_random_name() if not request_message.run_name else request_message.run_name
     run = _get_tracking_store().create_run(
         experiment_id=request_message.experiment_id,
         user_id=request_message.user_id,
         start_time=request_message.start_time,
         tags=tags,
-        run_name=run_name,
+        run_name=request_message.run_name,
     )
 
     response_message = CreateRun.Response()
@@ -877,6 +874,7 @@ def _get_run():
 @catch_mlflow_exception
 @_disable_if_artifacts_only
 def _search_runs():
+
     request_message = _get_request_message(
         SearchRuns(),
         schema={
@@ -995,26 +993,6 @@ def _get_metric_history():
     return response
 
 
-@catch_mlflow_exception
-@_disable_if_artifacts_only
-def _list_experiments():
-    request_message = _get_request_message(
-        ListExperiments(), schema={"max_results": [_assert_intlike], "page_token": [_assert_string]}
-    )
-    # `ListFields` returns a list of (FieldDescriptor, value) tuples for *present* fields:
-    # https://googleapis.dev/python/protobuf/latest/google/protobuf/message.html
-    # #google.protobuf.message.Message.ListFields
-    params = {field.name: val for field, val in request_message.ListFields()}
-    experiment_entities = _get_tracking_store().list_experiments(**params)
-    response_message = ListExperiments.Response()
-    response_message.experiments.extend([e.to_proto() for e in experiment_entities])
-    if experiment_entities.token:
-        response_message.next_page_token = experiment_entities.token
-    response = Response(mimetype="application/json")
-    response.set_data(message_to_json(response_message))
-    return response
-
-
 @catch_mlflow_exception
 @_disable_if_artifacts_only
 def _search_experiments():
@@ -1206,29 +1184,10 @@ def _delete_registered_model():
     return _wrap_response(DeleteRegisteredModel.Response())
 
 
-@catch_mlflow_exception
-@_disable_if_artifacts_only
-def _list_registered_models():
-    request_message = _get_request_message(
-        ListRegisteredModels(),
-        schema={
-            "max_results": [_assert_intlike, lambda x: _assert_less_than_or_equal(x, 1000)],
-            "page_token": [_assert_string],
-        },
-    )
-    registered_models = _get_model_registry_store().list_registered_models(
-        request_message.max_results, request_message.page_token
-    )
-    response_message = ListRegisteredModels.Response()
-    response_message.registered_models.extend([e.to_proto() for e in registered_models])
-    if registered_models.token:
-        response_message.next_page_token = registered_models.token
-    return _wrap_response(response_message)
-
-
 @catch_mlflow_exception
 @_disable_if_artifacts_only
 def _search_registered_models():
+
     request_message = _get_request_message(
         SearchRegisteredModels(),
         schema={
@@ -1302,36 +1261,6 @@ def _delete_registered_model_tag():
     return _wrap_response(DeleteRegisteredModelTag.Response())
 
 
-def _validate_source(source: str, run_id: str) -> None:
-    if is_local_uri(source):
-        if run_id:
-            store = _get_tracking_store()
-            run = store.get_run(run_id)
-            source = pathlib.Path(local_file_uri_to_path(source)).resolve()
-            run_artifact_dir = pathlib.Path(local_file_uri_to_path(run.info.artifact_uri)).resolve()
-            if run_artifact_dir in [source, *source.parents]:
-                return
-
-        raise MlflowException(
-            f"Invalid model version source: '{source}'. To use a local path as a model version "
-            "source, the run_id request parameter has to be specified and the local path has to be "
-            "contained within the artifact directory of the run specified by the run_id.",
-            INVALID_PARAMETER_VALUE,
-        )
-
-    # There might be file URIs that are local but can bypass the above check. To prevent this, we
-    # disallow using file URIs as model version sources by default unless it's explicitly allowed
-    # by setting the MLFLOW_ALLOW_FILE_URI_AS_MODEL_VERSION_SOURCE environment variable to True.
-    if not MLFLOW_ALLOW_FILE_URI_AS_MODEL_VERSION_SOURCE.get() and is_file_uri(source):
-        raise MlflowException(
-            f"Invalid model version source: '{source}'. MLflow tracking server doesn't allow using "
-            "a file URI as a model version source for security reasons. To disable this check, set "
-            f"the {MLFLOW_ALLOW_FILE_URI_AS_MODEL_VERSION_SOURCE.name} environment variable to "
-            "True.",
-            INVALID_PARAMETER_VALUE,
-        )
-
-
 @catch_mlflow_exception
 @_disable_if_artifacts_only
 def _create_model_version():
@@ -1346,7 +1275,6 @@ def _create_model_version():
             "description": [_assert_string],
         },
     )
-    _validate_source(request_message.source, request_message.run_id)
     model_version = _get_model_registry_store().create_model_version(
         name=request_message.name,
         source=request_message.source,
@@ -1371,7 +1299,6 @@ def get_model_version_artifact_handler():
     path = request_dict["path"]
     validate_path_is_safe(path)
     artifact_uri = _get_model_registry_store().get_model_version_download_uri(name, version)
-
     if _is_servable_proxied_run_artifact_root(artifact_uri):
         artifact_repo = _get_artifact_repo_mlflow_artifacts()
         artifact_path = _get_proxied_run_artifact_destination_path(
@@ -1529,7 +1456,6 @@ def _download_artifact(artifact_path):
     A request handler for `GET /mlflow-artifacts/artifacts/<artifact_path>` to download an artifact
     from `artifact_path` (a relative path from the root artifact directory).
     """
-    validate_path_is_safe(artifact_path)
     basename = posixpath.basename(artifact_path)
     tmp_dir = tempfile.TemporaryDirectory()
     artifact_repo = _get_artifact_repo_mlflow_artifacts()
@@ -1556,7 +1482,6 @@ def _upload_artifact(artifact_path):
     A request handler for `PUT /mlflow-artifacts/artifacts/<artifact_path>` to upload an artifact
     to `artifact_path` (a relative path from the root artifact directory).
     """
-    validate_path_is_safe(artifact_path)
     head, tail = posixpath.split(artifact_path)
     with tempfile.TemporaryDirectory() as tmp_dir:
         tmp_path = os.path.join(tmp_dir, tail)
@@ -1582,11 +1507,7 @@ def _list_artifacts_mlflow_artifacts():
     (a relative path from the root artifact directory).
     """
     request_message = _get_request_message(ListArtifactsMlflowArtifacts())
-    if request_message.HasField("path"):
-        validate_path_is_safe(request_message.path)
-        path = request_message.path
-    else:
-        path = None
+    path = request_message.path if request_message.HasField("path") else None
     artifact_repo = _get_artifact_repo_mlflow_artifacts()
     files = []
     for file_info in artifact_repo.list_artifacts(path):
@@ -1607,7 +1528,6 @@ def _delete_artifact_mflflow_artifacts(artifact_path):
     A request handler for `DELETE /mlflow-artifacts/artifacts?path=<value>` to delete artifacts in
     `path` (a relative path from the root artifact directory).
     """
-    validate_path_is_safe(artifact_path)
     _get_request_message(DeleteArtifact())
     artifact_repo = _get_artifact_repo_mlflow_artifacts()
     artifact_repo.delete_artifacts(artifact_path)
@@ -1626,9 +1546,9 @@ def _add_static_prefix(route):
 
 def _get_paths(base_path):
     """
-    A service endpoints base path is typically something like /preview/mlflow/experiment.
-    We should register paths like /api/2.0/preview/mlflow/experiment and
-    /ajax-api/2.0/preview/mlflow/experiment in the Flask router.
+    A service endpoints base path is typically something like /mlflow/experiment.
+    We should register paths like /api/2.0/mlflow/experiment and
+    /ajax-api/2.0/mlflow/experiment in the Flask router.
     """
     return ["/api/2.0{}".format(base_path), _add_static_prefix("/ajax-api/2.0{}".format(base_path))]
 
@@ -1686,7 +1606,6 @@ HANDLERS = {
     SearchRuns: _search_runs,
     ListArtifacts: _list_artifacts,
     GetMetricHistory: _get_metric_history,
-    ListExperiments: _list_experiments,
     SearchExperiments: _search_experiments,
     # Model Registry APIs
     CreateRegisteredModel: _create_registered_model,
@@ -1694,7 +1613,6 @@ HANDLERS = {
     DeleteRegisteredModel: _delete_registered_model,
     UpdateRegisteredModel: _update_registered_model,
     RenameRegisteredModel: _rename_registered_model,
-    ListRegisteredModels: _list_registered_models,
     SearchRegisteredModels: _search_registered_models,
     GetLatestVersions: _get_latest_versions,
     CreateModelVersion: _create_model_version,
